# Code generated from the linkML model

This directory holds the output generated with [LinkML generators](https://linkml.io/linkml/generators/index.html) from the model in `src/dcat_ap_plus/datamodel/schema/dcat_ap_plus.yaml`.

Generators transform a linkml schema into another datamodel such as SQL or RDF, or into other artefacts, such as JSON-Schema, a visualisation, or markdown documentation.

We only distribute selected model representations, such as SHACL or JSON-LD which we have checked and use ourselves.
If you need other representations, we suggest you to run the LinkML generators locally.
Create an [issue](https://github.com/nfdi-de/dcat-ap-plus/issues), if you need other generated model representations than the default set built for dcat-ap-plus.
